@@ -62,7 +62,7 @@ def wp(command):
 
 	click.echo('Spawning SSH and running WP-CLI on %s.sailed.io' % sail_config['app_id'], err=True)
 
-	os.execlp('ssh', 'ssh', '-t',
+	os.execlp('ssh', 'ssh', '-tt',
 		'-i', '%s/.sail/ssh.key' % root,
 		'-o', 'UserKnownHostsFile=%s/.sail/known_hosts' % root,
 		'-o', 'IdentitiesOnly=yes',
@@ -84,9 +84,10 @@ def admin():
 @click.option('--nginx-access', is_flag=True)
 @click.option('--nginx-error', '--nginx-errors', is_flag=True)
 @click.option('--php-error', '--php-errors', is_flag=True)
+@click.option('--postfix', '--mail', is_flag=True)
 @click.option('--follow', '-f', is_flag=True)
 @click.option('--lines', '-n', type=int)
-def logs(nginx, php, nginx_access, nginx_error, php_error, follow, lines):
+def logs(nginx, php, nginx_access, nginx_error, php_error, postfix, follow, lines):
 	'''Query and follow logs from the production server'''
 	root = util.find_root()
 	sail_config = util.get_sail_config()
@@ -108,15 +109,24 @@ def logs(nginx, php, nginx_access, nginx_error, php_error, follow, lines):
 	else:
 		settings.append('--lines 30')
 
+	if postfix:
+		settings.append('-t postfix/qmgr')
+		settings.append('-t postfix/pickup')
+		settings.append('-t postfix/master')
+		settings.append('-t postfix/smtp')
+		settings.append('-t postfix/cleanup')
+		settings.append('-t postfix/postsuper')
+		settings.append('-t postfix/postqueue')
+
 	settings = ' '.join(settings)
 
-	os.execlp('ssh', 'ssh', '-t',
+	os.execlp('ssh', 'ssh', '-tt',
 		'-i', '%s/.sail/ssh.key' % root,
 		'-o', 'UserKnownHostsFile=%s/.sail/known_hosts' % root,
 		'-o', 'IdentitiesOnly=yes',
 		'-o', 'IdentityFile=%s/.sail/ssh.key' % root,
 		'root@%s.sailed.io' % sail_config['app_id'],
-		'journalctl --no-hostname %s' % settings
+		'journalctl --no-hostname --directory=/var/log/journal %s' % settings
 	)
 
 @cli.command()
@@ -134,7 +144,7 @@ def ssh(root):
 
 	click.echo('Spawning an interactive SSH shell for %s.sailed.io' % sail_config['app_id'])
 
-	os.execlp('ssh', 'ssh', '-t',
+	os.execlp('ssh', 'ssh', '-tt',
 		'-i', '%s/.sail/ssh.key' % root,
 		'-o', 'UserKnownHostsFile=%s/.sail/known_hosts' % root,
 		'-o', 'IdentitiesOnly=yes',
